# Copyright (c) 2014 Scopely, Inc.
# Copyright (c) 2015 Mitch Garnaat
#
# Licensed under the Apache License, Version 2.0 (the "License"). You
# may not use this file except in compliance with the License. A copy of
# the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is
# distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
# ANY KIND, either express or implied. See the License for the specific
# language governing permissions and limitations under the License.

import logging

import jmespath

from skew.resources.aws import AWSResource


LOG = logging.getLogger(__name__)


class Cluster(AWSResource):

    class Meta(object):
        service = 'ecs'
        type = 'cluster'
        enum_spec = ('list_clusters', 'clusterArns', None)
        detail_spec = ('describe_clusters', 'clusters', 'clusters')
        id = 'clusterArn'
        filter_name = 'clusters'
        filter_type = 'list'
        name = 'clusterName'
        date = None
        dimension = 'clusterName'

    def __init__(self, client, data, query=None):
        super(Cluster, self).__init__(client, data, query)
        _, _, _, _, _, type_and_id = data.split(':')
        _, self._id = type_and_id.split('/')
        detail_op, param_name, detail_path = self.Meta.detail_spec
        params = {param_name: [self.id]}
        data = client.call(detail_op, **params)
        self.data = jmespath.search(detail_path, data)


class Service(AWSResource):

    class Meta(object):
        service = 'ecs'
        type = 'service'
        enum_spec = ('list_services', 'serviceArns', None)
        detail_spec = ('describe_services', 'services', 'services')
        id = 'serviceArn'
        filter_name = 'services'
        filter_type = 'list'
        name = 'serviceName'
        date = None
        dimension = 'serviceName'

    def __init__(self, client, data, query=None):
        super(Cluster, self).__init__(client, data, query)
        _, _, _, _, _, type_and_id = data.split(':')
        _, self._id = type_and_id.split('/')
        params = {'cluster': self.name}
        detail_op, param_name, detail_path = self.Meta.detail_spec
        params = {param_name: [self.id]}
        data = client.call(detail_op, **params)
        self.data = jmespath.search(detail_path, data)
